@@ -140,8 +140,7 @@ void SettingsBase::initToolBar()
     quitAction = actionCollection()->addAction( KStandardAction::Quit, QStringLiteral("quit_action"), this, SLOT(close()) );
     // Configure goes at the end
     configureAction = actionCollection()->addAction( KStandardAction::Preferences, QStringLiteral("configure"), this, SLOT(configShow()) );
-    actionCollection()->setDefaultShortcut(configureAction, QKeySequence(Qt::CTRL + Qt::Key_M));
-    configureAction->setText( i18n("Configure") );
+    configureAction->setText( i18n("Configure...") );
     // Help after it
     initHelpMenu();
     configureAction->setIcon(QIcon::fromTheme(QStringLiteral("settings-configure")));
@@ -316,7 +315,7 @@ void SettingsBase::about()
 
 void SettingsBase::changePlugin()
 {
-    if( possibleViews.count() == 0 ) { // We should ensure we have a plugin available to choose
+    if( possibleViews.isEmpty() ) { // We should ensure we have a plugin available to choose
         KMessageBox::error(this, i18n("System Settings was unable to find any views, and hence has nothing to display."), i18n("No views found"));
         close();
         return; // Halt now!
